<!DOCTYPE TS><TS>
<context>
    <name>PhoneUIBox</name>
    <message>
        <source>Add someone to your Directory </source>
        <translation>Jemanden zum Adressbuch hinzufügen</translation>
    </message>
    <message>
        <source>Edit this Entry</source>
        <translation>Eintrag editieren</translation>
    </message>
    <message>
        <source>Remove from Speed Dials</source>
        <translation>Aus der Kurzwahlliste entfernen</translation>
    </message>
    <message>
        <source>Save this in the Directory</source>
        <translation>Diesen Eintrag im Adressbuch speichern</translation>
    </message>
    <message>
        <source>Clear the Call History</source>
        <translation>Anrufliste löschen</translation>
    </message>
    <message>
        <source>Make this a Speeddial</source>
        <translation>zur Kurzwahlliste hinzufügen</translation>
    </message>
    <message>
        <source>Delete this Entry</source>
        <translation>Diesen Eintrag löschen</translation>
    </message>
    <message>
        <source>Delete this Voicemail</source>
        <translation>Sprachnachricht löschen</translation>
    </message>
    <message>
        <source>Delete all Voicemails</source>
        <translation>Alle Sprachnachrichten löschen</translation>
    </message>
    <message>
        <source>Place Videocall Now</source>
        <translation>Starte Videoanruf</translation>
    </message>
    <message>
        <source>Place Voice-Only Call Now</source>
        <translation>Starte Sprachanruf</translation>
    </message>
    <message>
        <source>Switch from digits to URL input</source>
        <translation>Von Zahlen- zur URL-Eingabe wechseln</translation>
    </message>
    <message>
        <source>Switch from URL to Digits input</source>
        <translation>Von URL- zur Zahlen-Eingabe wechseln</translation>
    </message>
    <message>
        <source>Send IM</source>
        <translation>Kurznachricht schicken</translation>
    </message>
    <message>
        <source>Save Changes</source>
        <translation>Änderungen speichern</translation>
    </message>
    <message>
        <source>ADD</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>ADD DIRECTORY</source>
        <translation>Adressbuch hinzufügen</translation>
    </message>
    <message>
        <source>Registered to</source>
        <translation type="obsolete">Registriert auf</translation>
    </message>
    <message>
        <source>as</source>
        <translation type="obsolete">als</translation>
    </message>
    <message>
        <source>Not Registered</source>
        <translation>Nicht registriert</translation>
    </message>
    <message>
        <source>Directory</source>
        <translation>Verzeichnis</translation>
    </message>
    <message>
        <source>Speed Dials</source>
        <translation>Kurzwahl</translation>
    </message>
    <message>
        <source>No Active Calls</source>
        <translation>Keine offenen Verbindungen</translation>
    </message>
    <message>
        <source>Caller is Leaving Voicemail</source>
        <translation>Anrufer hinterläßt eine Sprachnachricht</translation>
    </message>
    <message>
        <source>Trying to Contact Remote Party</source>
        <translation>Versuche, die Gegenstelle zu erreichen</translation>
    </message>
    <message>
        <source>Audio and Video Looped to </source>
        <translation>Audio und Video durchschleifen zu </translation>
    </message>
    <message>
        <source>Incoming Call</source>
        <translation>Eingehender Anruf</translation>
    </message>
    <message>
        <source>Hanging Up</source>
        <translation>Lege auf</translation>
    </message>
    <message>
        <source>Call History</source>
        <translation>Vorangegangene Anrufe</translation>
    </message>
    <message>
        <source>Voicemail</source>
        <translation>Sprachnachrichten</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Spitzname</translation>
    </message>
    <message>
        <source>First Name</source>
        <translation type="obsolete">Vorname</translation>
    </message>
    <message>
        <source>(Optional)</source>
        <translation type="obsolete">(Optional)</translation>
    </message>
    <message>
        <source>Surname</source>
        <translation type="obsolete">Nachname</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Default Photo</source>
        <translation>Bild</translation>
    </message>
    <message>
        <source>To Directory</source>
        <translation>Im Verzeichnis</translation>
    </message>
    <message>
        <source>Business Card</source>
        <translation>Visitenkarte</translation>
    </message>
    <message>
        <source>Latest Calls:</source>
        <translation>Letzte Anrufe:</translation>
    </message>
    <message>
        <source>Videocall</source>
        <translation type="obsolete">Videoanruf</translation>
    </message>
    <message>
        <source>Voice-Only</source>
        <translation type="obsolete">nur Sprache</translation>
    </message>
    <message>
        <source>Send an Instant Message</source>
        <translation>Eine Kurznachricht senden</translation>
    </message>
    <message>
        <source>You Called </source>
        <translation>Sie riefen an </translation>
    </message>
    <message>
        <source>They Called </source>
        <translation>Sie wurden angerufen </translation>
    </message>
    <message>
        <source>You missed their call </source>
        <translation>Sie haben den Anruf verpasst </translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="obsolete">Heute</translation>
    </message>
    <message>
        <source>Yesterday</source>
        <translation type="obsolete">Gestern</translation>
    </message>
    <message>
        <source>at</source>
        <translation>um</translation>
    </message>
    <message>
        <source> for %d min</source>
        <translation> für %d Min.</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Volume</source>
        <translation>Lautstärke</translation>
    </message>
    <message>
        <source>Mic Volume (not impl.)</source>
        <translation>Mikrofon-Lautstärke (nicht implementiert)</translation>
    </message>
    <message>
        <source>Brightness</source>
        <translation>Helligkeit</translation>
    </message>
    <message>
        <source>Contrast</source>
        <translation>Kontrast</translation>
    </message>
    <message>
        <source>Colour</source>
        <translation>Farbe</translation>
    </message>
    <message>
        <source>Transmit Video Size</source>
        <translation>Bildgröße der Videoübertragung</translation>
    </message>
    <message>
        <source>Transmit Video FPS</source>
        <translation>Wiederholrate der Videoübertragung</translation>
    </message>
    <message>
        <source>Up/Down - Change       Left/Right - Adjust</source>
        <translation>Pfeil-Auf/-Ab - Ändern       Pfeil-Links/-Rechts - Anpassen</translation>
    </message>
    <message>
        <source>Dial</source>
        <translation>Wählen</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">Ok</translation>
    </message>
    <message>
        <source>A directory entry already exists with this URL.</source>
        <translation type="obsolete">Es existiert bereits ein Eintrag mit dieser URL.</translation>
    </message>
    <message>
        <source>Registered to </source>
        <translation>Registriert bei </translation>
    </message>
    <message>
        <source> as </source>
        <translation> als </translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Verbinde...</translation>
    </message>
    <message>
        <source>First Name (Optional)</source>
        <translation>Vorname (optional)</translation>
    </message>
    <message>
        <source>Surname (Optional)</source>
        <translation>Nachname (optional)</translation>
    </message>
    <message>
        <source>Speed Dial</source>
        <translation>Kurzwahl</translation>
    </message>
    <message>
        <source>Client is on My Home LAN</source>
        <translation>Gegenstelle befindet sich in meinem LAN</translation>
    </message>
    <message>
        <source> Videocall</source>
        <translation> Videoanruf</translation>
    </message>
    <message>
        <source> Voice-Only</source>
        <translation> Nur-Sprache</translation>
    </message>
    <message>
        <source>Today </source>
        <translation>Heute </translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>Gestern </translation>
    </message>
    <message>
        <source>Packets In/Out/Lost/Late:             </source>
        <translation>Pakete (Eingehend/Ausgehend/Verloren/Verspätet): </translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Resolution In/Out: </source>
        <translation>Auflösung (Eingehend/Ausgehend): </translation>
    </message>
    <message>
        <source>Packets In/Lost/Disc/Late: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Packets Out/Dropped: </source>
        <translation>Pakete (Ausgehend/Verworfen): </translation>
    </message>
    <message>
        <source>Video Frames In/Out/Disc: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Average FPS In/Out: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Webcam Frames Delivered/Dropped: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Packets In/Out/Lost/Late: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio Codec</source>
        <translation>Audio-Codec</translation>
    </message>
    <message>
        <source>Playout Delay Min/Avg/Max:            </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Packets Lost by Peer:                 </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Packets Lost by Peer: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Playout Delay Min/Avg/Max: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Webcam device</source>
        <translation>Webcam-Gerät</translation>
    </message>
    <message>
        <source>Select the device path your webcam is using. If you have a capture card it may be using /dev/video so try dev/video1</source>
        <translation>Wählen Sie die Gerätedatei für Ihre Webcam. Falls schon ein anderes Aufnahmegerät /dev/video benutzt, bitte /dev/video1 versuchen.</translation>
    </message>
    <message>
        <source>Transmit Resolution</source>
        <translation>Übertragungs-Auflösung</translation>
    </message>
    <message>
        <source>176x144</source>
        <translation type="obsolete">176x144</translation>
    </message>
    <message>
        <source>128x96</source>
        <translation type="obsolete">128x96</translation>
    </message>
    <message>
        <source>704x576</source>
        <translation type="obsolete">704x576</translation>
    </message>
    <message>
        <source>352x288</source>
        <translation type="obsolete">352x288</translation>
    </message>
    <message>
        <source>Size of video window to transmit; higher resolutions require more bandwidth.</source>
        <translation>Die Videobildgröße, die übertragen werden soll; höhere Auflösungen benötigen mehr Bandbreite.</translation>
    </message>
    <message>
        <source>Capture Resolution</source>
        <translation>Aufnahme-Auflösung</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation type="obsolete">320x240</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation type="obsolete">160x120</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation type="obsolete">640x480</translation>
    </message>
    <message>
        <source>Size of video source from your webcam. Choose a value compatible with your webcam hardware. Choose higher values to digitally pan/zoom before transmission.</source>
        <translation>Größe des Videosignals der Webcam. Bitte einen Wert wählen, der kompatibel ist mit der Webcam. Größere Werte auswählen, falls das Bild digital verschoben bzw. vergrößert werden soll vor der Übertragung.</translation>
    </message>
    <message>
        <source>Transmit Frames/Second</source>
        <translation>Übertrage Bilder/Sekunde</translation>
    </message>
    <message>
        <source>Number of webcam frames/sec to transmit, from 1 to 30. Higher numbers create better results but use more bandwidth.</source>
        <translation>Anzahl der zu übertragenden Webcam-Bilder/sec, zwischen 1 und 30. Höhere Werte erzeugen bessere Ergebnisse, benötigen aber mehr Bandbreite.</translation>
    </message>
    <message>
        <source>Time to Answer</source>
        <translation>Zeit zum Antworten</translation>
    </message>
    <message>
        <source>10</source>
        <translation type="obsolete">10</translation>
    </message>
    <message>
        <source>The time in seconds a call rings before being automatically answered and diverted to a VXML script.</source>
        <translation>Zeit in Sekunden bevor ein Anruf automatisch beantwortet und zu einem VXML-Skript umgeleitet wird.</translation>
    </message>
    <message>
        <source>Default VXML URL</source>
        <translation>Standard VXML-Adresse</translation>
    </message>
    <message>
        <source>http://127.0.0.1/vxml/index.vxml</source>
        <translation type="obsolete">http://127.0.0.1/vxml/index.vxml</translation>
    </message>
    <message>
        <source>The URL to retrieve a VXML script which can be used to prompt for leaving a voicemail etc. Leave blank if you have no HTTP server and a default Voicemail script will be used.</source>
        <translation>Die URL eines VXML-Skripts, das für Sprachnachrichten usw. benutzt werden soll. Falls SIe keinen HTTP-Server betreiben wird ein Standardskript verwendet.</translation>
    </message>
    <message>
        <source>Default Voicemail Prompt</source>
        <translation>Standard-Ansagetext</translation>
    </message>
    <message>
        <source>I am not at home, please leave a message after the tone</source>
        <translation>Ich bin derzeit nicht erreichbar, bitte hinterlassen Sie nach dem Piepston eine Nachricht</translation>
    </message>
    <message>
        <source>Either a text message to be read by the TTS engine or the filename of a .wav file to be played to callers. Only used where the above setting is blank.</source>
        <translation>Entweder eine Textnachricht, die von der TTS Software vorgelesen werden soll oder der Dateiname einer WAV-Datei, die den Anrufern vorgespielt wird. Wird nur benötigt, falls der vorherige Eintrag leer ist.</translation>
    </message>
    <message>
        <source>Text to Speech Voice</source>
        <translation>Vorlesestimme</translation>
    </message>
    <message>
        <source>Choose a voice to use from the Text To Speech library. </source>
        <translation>Wählen Sie eine Vorlesestimme aus der Liste.</translation>
    </message>
    <message>
        <source>Allows you to register with services such as Free World Dialup; or with applications like Asterisk. Restart mythfrontend if you change this.</source>
        <translation>Erlaubt das Anmelden bei einem SIP-Service wie Free World Dial oder bei Programmen wie Asterisk. Bei Änderungen wird ein Neustart von Mythfrontend notwendig.</translation>
    </message>
    <message>
        <source>Name of the Proxy, such as fwd.pulver.com for Free World Dialup.</source>
        <translation>Name des SIP-Proxys, z.B. fwd.pulver.com bei Free World Dialup.</translation>
    </message>
    <message>
        <source>SIP Local Port</source>
        <translation>Lokaler SIP-Port</translation>
    </message>
    <message>
        <source>5060</source>
        <translation type="obsolete">5060</translation>
    </message>
    <message>
        <source>The port on this machine to use. You may need to make these different for each Mythfrontend and setup your firewall to let this port through.</source>
        <translation>Port, der auf diesem Rechner benutzt werden soll. Dieser Port sollte auf jedem Frontend unterschiedlich und in der Firewall freigeschaltet sein.</translation>
    </message>
    <message>
        <source>Microphone device</source>
        <translation>Mikrofon-Gerät</translation>
    </message>
    <message>
        <source>Select the device path for your microphone. Currently this CANNOT be the same device as used for audio output.</source>
        <translation>Gerätepfad für das Mikrofon auswählen. Derzeit es darf NICHT das gleiche Gerät sein, das als Tonausgang benutzt wird.</translation>
    </message>
    <message>
        <source>My Display Name</source>
        <translation>Angezeigter Name</translation>
    </message>
    <message>
        <source>My common name to display when I call other people. </source>
        <translation>Der Name, der erscheinen soll, wenn andere von mir angerufen werden.</translation>
    </message>
    <message>
        <source>Codecs Supported</source>
        <translation>Unterstützte Codecs</translation>
    </message>
    <message>
        <source>The list of codecs to use, in the preferred order separated by semicolon. Supported codecs are G.711u, G.711a and GSM.</source>
        <translation>Liste der Codecs, die benutzt werden sollen in der bevorzugten Reihenfolge (getrennt durch Semikolons). Unterstützte Codecs sind G.711u, G.711a und GSM.</translation>
    </message>
    <message>
        <source>SIP Network Interface</source>
        <translation>SIP Netzwerk-Schnittstelle</translation>
    </message>
    <message>
        <source>eth0</source>
        <translation type="obsolete">eth0</translation>
    </message>
    <message>
        <source>Enter the name of the network to bind to e.g. eth0</source>
        <translation>Bezeichnung des Netzwerkgeräts eingeben (z.B. eth0)</translation>
    </message>
    <message>
        <source>NAT Traversal Method</source>
        <translation>NAT-Methode</translation>
    </message>
    <message>
        <source>NAT IP Address</source>
        <translation>NAT IP-Adresse</translation>
    </message>
    <message>
        <source>http://checkip.dyndns.org</source>
        <translation>http://checkip.dyndns.org</translation>
    </message>
    <message>
        <source>If you selected MANUAL above, then enter your Public IP Address here. If you selected WEB Server above then enter your web server URL here.</source>
        <translation>Eine öffentliche IP-Adresse eingeben, wenn zuvor &apos;Manual&apos; ausgewählt wurde. Die Adresse des Web-Servers eingeben, falls zuvor &apos;Web-Server&apos; ausgewählt wurde.</translation>
    </message>
    <message>
        <source>Audio RTP Port</source>
        <translation>Audio-RTP Port</translation>
    </message>
    <message>
        <source>Enter the port to use for Audio RTP; an even number between 1024 and 32767. If you have a firewall you should enable UDP through the firewall on this port.</source>
        <translation>Port eingeben, der für Audio-RTP benutzt werden soll; eine gerade Zahl zwischen 1024 und 32767. Falls eine Firewall vorhanden ist, sollte dort für diesen Port UDP freigeschaltet werden.</translation>
    </message>
    <message>
        <source>Video RTP Port</source>
        <translation>Video-RTP Port</translation>
    </message>
    <message>
        <source>Enter the port to use for Video RTP; an even number between 1024 and 32767. If you have a firewall you should enable UDP through the firewall on this port.</source>
        <translation>Port eingeben, der für Video-RTP benutzt werden soll; eine gerade Zahl zwischen 1024 und 32767. Falls eine Firewall vorhanden ist, sollte dort für diesen Port UDP freigeschaltet werden.</translation>
    </message>
    <message>
        <source>Auto-Answer</source>
        <translation>Autom. Antwort</translation>
    </message>
    <message>
        <source>When the MythFrontend is in the MythPhone plugin, setting this automatically answers all incoming calls. There is no security yet.</source>
        <translation>Wenn MythFrontend sich im MythPhone-Plugin befindet, aktiviert diese Option das automatische Antworten auf eingehende Anrufe. Dabei gibt noch keine Sicherheitsmaßnahmen.</translation>
    </message>
    <message>
        <source>SIP Proxy Settings</source>
        <translation>SIP-Proxy Einstellungen</translation>
    </message>
    <message>
        <source>SIP Settings</source>
        <translation type="obsolete">SIP-Einstellungen</translation>
    </message>
    <message>
        <source>VXML Settings</source>
        <translation>VXML-Einstellungen</translation>
    </message>
    <message>
        <source>WEBCAM Settings</source>
        <translation>Webcam-Einstellungen</translation>
    </message>
    <message>
        <source>Login to a SIP Server</source>
        <translation>Anmelden am SIP-Server</translation>
    </message>
    <message>
        <source>SIP Server DNS Name</source>
        <translation>DNS-Name des SIP-Servers</translation>
    </message>
    <message>
        <source>Sign-in Name</source>
        <translation>Anmeldename</translation>
    </message>
    <message>
        <source>Your username for authentication with the SIP Server. For FWD this is your FWD number.</source>
        <translation>Benutzername für die Authentifizierung am SIP-Server. Bei Free World Dial ist es z.B. die FWD-Nummer.</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Your password for authentication with the SIP Server.</source>
        <translation>Ihr Passwort für die Authentifizierung am SIP-Server.</translation>
    </message>
    <message>
        <source>Method to use for NAT traversal; needs a Frontend restart after changing. Choose NONE if you have a public IP address, choose MANUAL if your ISP always gives you the same public address and manually enter this address below. Choose Web Server if you have a dynamic NAT address and enter a web address like http://checkip.dyndns.org below. </source>
        <translation>Methode zum NAT-Überqueren; Änderungen benötigen einen Neustart des Frontends. &apos;None&apos; wählen, wenn eine öffentliche IP-Adresse benutzt wird, &apos;Manual&apos; falls der ISP immer die gleiche öffentliche Adresse vergibt (unten eingeben). &apos;Web Server&apos; wählen, falls eine dynamische NAT-Adresse benutzt wird; dabei eine Adresse eingeben wie z.B.: http://checkip.dyndns.org.</translation>
    </message>
    <message>
        <source>Speed Dials</source>
        <translation>Kurzwahl</translation>
    </message>
    <message>
        <source>Voicemail</source>
        <translation>Sprachnachrichten</translation>
    </message>
    <message>
        <source>Placed Calls</source>
        <translation>Anrufe</translation>
    </message>
    <message>
        <source>Received Calls</source>
        <translation>empf. Anrufe</translation>
    </message>
    <message>
        <source>A directory entry already exists with this URL.</source>
        <translation>Es existiert bereits ein Eintrag mit dieser URL.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Max Transmit Bandwidth Kbps</source>
        <translation>Max. Übertragungsbandbreite (Kbps)</translation>
    </message>
    <message>
        <source>Enter the upspeed bandwidth of your local WAN in Kbps. </source>
        <translation>Geben Sie die Upload-Bandbreite ihrer Internetverbindung in Kbps an.</translation>
    </message>
    <message>
        <source>Me</source>
        <translation>Ich</translation>
    </message>
    <message>
        <source>Jitter Buffer (Audio Call)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size of the playout buffer in ms for an audio call. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jitter Buffer (Video Call)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size of the playout buffer in ms for a video call. This should be bigger than for an audio call because CPU usage causes jitter and to sync video &amp; audio.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IP Settings</source>
        <translation>IP-Einstellungen</translation>
    </message>
    <message>
        <source>AUDIO Settings</source>
        <translation>Audio-Einstellungen</translation>
    </message>
</context>
</TS>
